wellformednesstools.is_well_formed_component
============================================

.. autofunction:: abjad.tools.wellformednesstools.is_well_formed_component.is_well_formed_component
   :noindex:
